# GCP Cloud Run manager terraform module

This module manages a Cloud Run-hosted container. It takes care of making
sure the container is connected to a Cloud SQL instance and sets
environment variables on the application.

Specify the project to deploy into on the command line. So, for
example, to deploy to the project ``my-project``:

```console
$ terraform init
$ terraform apply -var project=my-project
```

In this example, terraform is configured to use default application credentials.
For Google APIs and these credentials should correspond to a user with owner or
editor access to the target project. You can use the ``gcloud`` command line
tool to set your personal credentials as application default credentials. See
the ``gcloud auth application-default`` command output for more information.

## Custom domain mapping

Setting the `dns_name` will create a domain mapping for the webapp. Before
setting this value you *must* have verified ownership of the domain with Google.
[Instructions on how to do
this](https://guidebook.devops.uis.cam.ac.uk/en/latest/notes/google-domain-verification/)
can be found in the DevOps division guidebook.

## Monitoring and Alerting
If the variable [alerting_email_address](variables.tf) is set, the module adds
basic uptime alerting via email for failing http polling. See [variables.tf](variables.tf)
for how to configure alerting and monitoring.

Note that monitoring and alerting  must be in a Stackdriver monitoring workspace 
and this must be configured manually, at the time of writing this.
